@@ -1,6 +1,5 @@
-/*	$Id$ */
 /*
- * Copyright (c) 2012, 2014--2018 Kristaps Dzonsons <kristaps@bsd.lv>
+ * Copyright (c) Kristaps Dzonsons <kristaps@bsd.lv>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -57,7 +56,7 @@
 /*
  * Build version.
  */
-#define	KCGI_VBUILD	3
+#define	KCGI_VBUILD	4
 
 /*
  * Version string of major.minor.build (as a literal string).
@@ -139,6 +138,8 @@ enum	krequ {
 	KREQU_ACCEPT_CHARSET,
 	KREQU_ACCEPT_ENCODING,
 	KREQU_ACCEPT_LANGUAGE,
+	KREQU_ACCESS_CONTROL_REQUEST_HEADERS,
+	KREQU_ACCESS_CONTROL_REQUEST_METHOD,
 	KREQU_AUTHORIZATION,
 	KREQU_DEPTH,
 	KREQU_FROM,
@@ -150,6 +151,7 @@ enum	krequ {
 	KREQU_IF_RANGE,
 	KREQU_IF_UNMODIFIED_SINCE,
 	KREQU_MAX_FORWARDS,
+	KREQU_ORIGIN,
 	KREQU_PROXY_AUTHORIZATION,
 	KREQU_RANGE,
 	KREQU_REFERER,
@@ -158,7 +160,12 @@ enum	krequ {
 };
 
 enum	kresp {
+	KRESP_ACCESS_CONTROL_ALLOW_CREDENTIALS,
+	KRESP_ACCESS_CONTROL_ALLOW_HEADERS,
+	KRESP_ACCESS_CONTROL_ALLOW_METHODS,
 	KRESP_ACCESS_CONTROL_ALLOW_ORIGIN,
+	KRESP_ACCESS_CONTROL_EXPOSE_HEADERS,
+	KRESP_ACCESS_CONTROL_MAX_AGE,
 	KRESP_ACCEPT_RANGES,
 	KRESP_AGE,
 	KRESP_ALLOW,
