@@ -16,6 +16,10 @@
  */
 #ifndef KCGIHTML_H
 #define KCGIHTML_H
+/*
+ * The only visible symbols should be those in this header file.
+ */
+#pragma GCC visibility push(default)
 
 #if !defined(__BEGIN_DECLS)
 #  ifdef __cplusplus
@@ -333,6 +337,7 @@ enum	kattr {
 	KATTR_REQUIRED,
 	KATTR_REV,
 	KATTR_REVERSED,
+	KATTR_ROLE,
 	KATTR_ROWS,
 	KATTR_ROWSPAN,
 	KATTR_SANDBOX,
@@ -519,4 +524,5 @@ enum kcgi_err	 khtml_write(const char *, size_t, void *);
 
 __END_DECLS
 
+#pragma GCC visibility pop /* visibility(default) */
 #endif
