@@ -16,6 +16,10 @@
  */
 #ifndef KCGIXML_H
 #define KCGIXML_H
+/*
+ * The only visible symbols should be those in this header file.
+ */
+#pragma GCC visibility push(default)
 
 #if !defined(__BEGIN_DECLS)
 #  ifdef __cplusplus
@@ -63,4 +67,5 @@ enum kcgi_err	 kxml_write(const char *, size_t, void *);
 
 __END_DECLS
 
+#pragma GCC visibility pop /* visibility(default) */
 #endif
